@@ -335,22 +335,35 @@ func buildDriverTable() string {
 	return s + "\n" + buildTableLinks(baseDrivers, mostDrivers, allDrivers)
 }
 
+var baseOrder = map[string]int{
+	"postgres":  0,
+	"mysql":     1,
+	"sqlserver": 2,
+	"oracle":    3,
+	"sqlite3":   4,
+	"csvq":      5,
+}
+
 func buildRows(m map[string]DriverInfo, widths []int) ([][]string, []int) {
 	var drivers []DriverInfo
 	for _, v := range m {
 		drivers = append(drivers, v)
 	}
 	sort.Slice(drivers, func(i, j int) bool {
+		switch {
+		case drivers[i].Group == "base":
+			return baseOrder[drivers[i].Driver] < baseOrder[drivers[j].Driver]
+		}
 		return strings.ToLower(drivers[i].Desc) < strings.ToLower(drivers[j].Desc)
 	})
 	var rows [][]string
 	for i, v := range drivers {
 		notes := ""
 		if v.CGO {
-			notes = "<sup>[†][f-cgo]</sup>"
+			notes = " <sup>[†][f-cgo]</sup>"
 		}
 		if v.Wire {
-			notes = "<sup>[‡][f-wire]</sup>"
+			notes = " <sup>[‡][f-wire]</sup>"
 		}
 		rows = append(rows, []string{
 			v.Desc,
